==> taskrun-4.0.0.tar.gz: taskrun-4.0.0/taskrun/__init__.py <==
"""
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * - Neither the name of prim nor the names of its contributors may be used to
 * endorse or promote products derived from this software without specific prior
 * written permission.
 *
 * See the NOTICE file distributed with this work for additional information
 * regarding copyright ownership.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
"""

from .cluster_task import ClusterTask
from .condition import Condition
from .counter_resource import CounterResource
from .cpu_time_resource import CpuTimeResource
from .failure_mode import FailureMode
from .file_cleanup_observer import FileCleanupObserver
from .file_hash_condition import FileHashCondition
from .file_hash_database import FileHashDatabase
from .file_modification_condition import FileModificationCondition
from .function_condition import FunctionCondition
from .function_task import FunctionTask
from .memory_resource import MemoryResource
from .nop_task import NopTask
from .observer import Observer
from .process_task import ProcessTask
from .resource import Resource
from .resource_manager import ResourceManager
from .task import Task
from .task_manager import TaskManager
from .verbose_observer import VerboseObserver

__version__ = '4.0.0'

==> taskrun-4.1.0.tar.gz: taskrun-4.1.0/taskrun/__init__.py <==
"""
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * - Neither the name of prim nor the names of its contributors may be used to
 * endorse or promote products derived from this software without specific prior
 * written permission.
 *
 * See the NOTICE file distributed with this work for additional information
 * regarding copyright ownership.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
"""

from .cluster_task import ClusterTask
from .common_instantiations import serial_task_manager
from .common_instantiations import standard_task_manager
from .condition import Condition
from .counter_resource import CounterResource
from .cpu_time_resource import CpuTimeResource
from .failure_mode import FailureMode
from .file_cleanup_observer import FileCleanupObserver
from .file_hash_condition import FileHashCondition
from .file_hash_database import FileHashDatabase
from .file_modification_condition import FileModificationCondition
from .function_condition import FunctionCondition
from .function_task import FunctionTask
from .memory_resource import MemoryResource
from .nop_task import NopTask
from .observer import Observer
from .process_task import ProcessTask
from .resource import Resource
from .resource_manager import ResourceManager
from .task import Task
from .task_manager import TaskManager
from .verbose_observer import VerboseObserver

__version__ = '4.1.0'
